#
# spec file for package qd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libqd0
Name:           qd
Version:        2.3.24
Release:        1.5
Summary:        Quad Double computation package
License:        BSD-3-Clause-LBNL
Group:          Development/Libraries/C and C++
URL:            https://www.davidhbailey.com/dhbsoftware/
Source0:        https://www.davidhbailey.com/dhbsoftware/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  pkg-config

%description
qd provides numeric types of twice the precision of IEEE double
(106 mantissa bits, or approximately 32 decimal digits) and four
times the precision of IEEE double (212 mantissa bits, or approximately
64 decimal digits).  Due to features such as operator and function
overloading, these facilities can be utilized with only minor modifications
to conventional C++ and Fortran-90 programs.

%package -n %{libname}
Summary:        A library for nonlinear optimization
Group:          System/Libraries

%description -n %{libname}
qd provides numeric types of twice the precision of IEEE double
(106 mantissa bits, or approximately 32 decimal digits) and four
times the precision of IEEE double (212 mantissa bits, or approximately
64 decimal digits).  Due to features such as operator and function
overloading, these facilities can be utilized with only minor modifications
to conventional C++ and Fortran-90 programs.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%setup -q

%build
%configure --enable-shared --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

rm -rf %{buildroot}%{_datadir}/doc/qd

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license COPYING
%{_libdir}/*.so.*

%files devel
%license COPYING
%doc AUTHORS docs/qd.pdf NEWS README
%{_bindir}/%{name}-config
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/qd.pc

%changelog
* Tue Feb 27 2024 jun wang <jgwang@suse.com>
- Update to version 2.3.24
  * Installed a patch suggested by Sharlatan Hellseher to improve the
    accuracy of a spherical geometry application.
  * Add BuildRequires package "autoconf"
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 2.3.23:
  * Fixed underlinking of libqdmod and libqd_f_main (bug).
  * Don't set CC=$CXX (fixes a new build issue with autoconf-2.71, bug).
  * Fixed typo in the rule to build docs/qd.pdf (bug).
  * Fixed "make dist" rule (built headers cannot be dist'd, bug).
  * Fixed the build with --disable-inline (bug).
  * Don't add "-O2" to CXXFLAGS or FCFLAGS when they're empty (portability).
  * Don't manually search for compilers & flags in configure.ac (portability).
  * Removed the --enable-warnings and --enable-debug flags (portability).
  * Modernized all of configure.ac for use with autoconf-2.71 (housekeeping).
* Mon Feb 25 2019 Klaus Kämpf <kkaempf@suse.com>
- Update to version 2.3.22
  Changes for 2.3.22
    Made changes suggested by Vasiliy Sotnikov
  Changes for 2.3.21
    Changed renorm in include/qd/qd_inline.h
  Changes for 2.3.20
    added #include <string.h> to quadt_test.cpp
    changed references to 2.3.20 from 2.3.18
  Changes for 2.3.19
  - Updated qd_real.cpp and dd_real.cpp to fix a
    buffer overflow problem.
  Changes for 2.3.18
  - Updated qd_real.cpp and dd_real.cpp to fix a problem in output.
  Changes for 2.3.17
  - updated qd_real.cpp, to fix a problem with improper treatment of
    negative arguments in nroot.
  Changes for 2.3.16
  - Updated dd_real.cpp, to fix a problem with inaccurate values
    of tanh for small arguments.
- License changed to BSD-3-Clause-LBNL
* Wed Nov  5 2014 dmitry_r@opensuse.org
- Update to version 2.3.15
  * bugfix release, see included ChangeLog for details
* Mon Aug 20 2012 scorot@free.fr
- spec file enhancement
* Mon Aug 20 2012 scorot@free.fr
- fix devel package dependency
* Sun Aug 19 2012 scorot@free.fr
- fix Source0 file extension
* Sun Aug 19 2012 scorot@free.fr
- first package
